pub struct InvoiceSummary {
pub additional_charge_summaries: Option<Vec<InvoiceSummaryAdditionalChargeSummary>>,
pub customer_balance: Option<Amount>,
pub google_balance: Option<Amount>,
pub merchant_balance: Option<Amount>,
pub product_total: Option<Amount>,
pub promotion_summaries: Option<Vec<Promotion>>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
additional_charge_summaries: Option<Vec<InvoiceSummaryAdditionalChargeSummary>>Summary of the total amounts of the additional charges.
customer_balance: Option<Amount>[required] Customer balance on this invoice. A negative amount means the customer is paying, a positive one means the customer is receiving money. Note: the sum of merchant_balance, customer_balance and google_balance must always be zero.
Furthermore the absolute value of this amount is expected to be equal to the sum of product amount and additional charges, minus promotions.
google_balance: Option<Amount>[required] Google balance on this invoice. A negative amount means Google is paying, a positive one means Google is receiving money. Note: the sum of merchant_balance, customer_balance and google_balance must always be zero.
merchant_balance: Option<Amount>[required] Merchant balance on this invoice. A negative amount means the merchant is paying, a positive one means the merchant is receiving money. Note: the sum of merchant_balance, customer_balance and google_balance must always be zero.
product_total: Option<Amount>[required] Total price for the product.
promotion_summaries: Option<Vec<Promotion>>Summary for each promotion.