pub struct OrderpaymentMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on orderpayment resources.
It is not used directly, but through the ShoppingContent hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_content2_sandbox as content2_sandbox;
use content2_sandbox::{ShoppingContent, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = ShoppingContent::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `notifyauthapproved(...)`, `notifyauthdeclined(...)`, `notifycharge(...)` and `notifyrefund(...)`
// to build up your call.
let rb = hub.orderpayments();Implementations
Sourceimpl<'a, C> OrderpaymentMethods<'a, C>
impl<'a, C> OrderpaymentMethods<'a, C>
Sourcepub fn notifyauthapproved(
&self,
request: OrderpaymentsNotifyAuthApprovedRequest,
merchant_id: u64,
order_id: &str,
) -> OrderpaymentNotifyauthapprovedCall<'a, C>
pub fn notifyauthapproved( &self, request: OrderpaymentsNotifyAuthApprovedRequest, merchant_id: u64, order_id: &str, ) -> OrderpaymentNotifyauthapprovedCall<'a, C>
Create a builder to help you perform the following task:
Notify about successfully authorizing user’s payment method for a given amount.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order for for which payment authorization is happening.
Sourcepub fn notifyauthdeclined(
&self,
request: OrderpaymentsNotifyAuthDeclinedRequest,
merchant_id: u64,
order_id: &str,
) -> OrderpaymentNotifyauthdeclinedCall<'a, C>
pub fn notifyauthdeclined( &self, request: OrderpaymentsNotifyAuthDeclinedRequest, merchant_id: u64, order_id: &str, ) -> OrderpaymentNotifyauthdeclinedCall<'a, C>
Create a builder to help you perform the following task:
Notify about failure to authorize user’s payment method.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order for which payment authorization was declined.
Sourcepub fn notifycharge(
&self,
request: OrderpaymentsNotifyChargeRequest,
merchant_id: u64,
order_id: &str,
) -> OrderpaymentNotifychargeCall<'a, C>
pub fn notifycharge( &self, request: OrderpaymentsNotifyChargeRequest, merchant_id: u64, order_id: &str, ) -> OrderpaymentNotifychargeCall<'a, C>
Create a builder to help you perform the following task:
Notify about charge on user’s selected payments method.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order for which charge is happening.
Sourcepub fn notifyrefund(
&self,
request: OrderpaymentsNotifyRefundRequest,
merchant_id: u64,
order_id: &str,
) -> OrderpaymentNotifyrefundCall<'a, C>
pub fn notifyrefund( &self, request: OrderpaymentsNotifyRefundRequest, merchant_id: u64, order_id: &str, ) -> OrderpaymentNotifyrefundCall<'a, C>
Create a builder to help you perform the following task:
Notify about refund on user’s selected payments method.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order for which charge is happening.