pub struct OrderpaymentsNotifyAuthDeclinedRequest {
pub decline_reason: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notifyauthdeclined orderpayments (request)
Fields
decline_reason: Option<String>Reason why payment authorization was declined.