pub struct OrderpaymentsNotifyRefundRequest {
pub invoice_id: Option<String>,
pub invoice_ids: Option<Vec<String>>,
pub refund_state: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notifyrefund orderpayments (request)
Fields
invoice_id: Option<String>Deprecated. Please use invoiceIds instead.
invoice_ids: Option<Vec<String>>Invoice IDs from the orderinvoices service that correspond to the refund.
refund_state: Option<String>Whether refund was successful.