pub struct OrderpaymentsNotifyRefundResponse {
pub execution_status: Option<String>,
pub kind: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notifyrefund orderpayments (response)
Fields
execution_status: Option<String>The status of the execution.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “content#orderpaymentsNotifyRefundResponse”.