pub struct ShipmentInvoiceLineItemInvoice {
pub line_item_id: Option<String>,
pub product_id: Option<String>,
pub shipment_unit_ids: Option<Vec<String>>,
pub unit_invoice: Option<UnitInvoice>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
line_item_id: Option<String>ID of the line item. Either lineItemId or productId must be set.
product_id: Option<String>ID of the product. This is the REST ID used in the products service. Either lineItemId or productId must be set.
shipment_unit_ids: Option<Vec<String>>[required] Unit IDs to define specific units within the line item.
unit_invoice: Option<UnitInvoice>[required] Invoice details for a single unit.