pub struct OrderMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on order resources.
It is not used directly, but through the ShoppingContent hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_content2_sandbox as content2_sandbox;
use content2_sandbox::{ShoppingContent, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = ShoppingContent::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `acknowledge(...)`, `advancetestorder(...)`, `cancel(...)`, `cancellineitem(...)`, `canceltestorderbycustomer(...)`, `createtestorder(...)`, `createtestreturn(...)`, `custombatch(...)`, `get(...)`, `getbymerchantorderid(...)`, `gettestordertemplate(...)`, `instorerefundlineitem(...)`, `list(...)`, `refund(...)`, `rejectreturnlineitem(...)`, `returnlineitem(...)`, `returnrefundlineitem(...)`, `setlineitemmetadata(...)`, `shiplineitems(...)`, `updatelineitemshippingdetails(...)`, `updatemerchantorderid(...)` and `updateshipment(...)`
// to build up your call.
let rb = hub.orders();Implementations
Sourceimpl<'a, C> OrderMethods<'a, C>
impl<'a, C> OrderMethods<'a, C>
Sourcepub fn acknowledge(
&self,
request: OrdersAcknowledgeRequest,
merchant_id: u64,
order_id: &str,
) -> OrderAcknowledgeCall<'a, C>
pub fn acknowledge( &self, request: OrdersAcknowledgeRequest, merchant_id: u64, order_id: &str, ) -> OrderAcknowledgeCall<'a, C>
Create a builder to help you perform the following task:
Marks an order as acknowledged.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn advancetestorder(
&self,
merchant_id: u64,
order_id: &str,
) -> OrderAdvancetestorderCall<'a, C>
pub fn advancetestorder( &self, merchant_id: u64, order_id: &str, ) -> OrderAdvancetestorderCall<'a, C>
Create a builder to help you perform the following task:
Sandbox only. Moves a test order from state “inProgress” to state “pendingShipment”.
Arguments
merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the test order to modify.
Sourcepub fn cancel(
&self,
request: OrdersCancelRequest,
merchant_id: u64,
order_id: &str,
) -> OrderCancelCall<'a, C>
pub fn cancel( &self, request: OrdersCancelRequest, merchant_id: u64, order_id: &str, ) -> OrderCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancels all line items in an order, making a full refund.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order to cancel.
Sourcepub fn cancellineitem(
&self,
request: OrdersCancelLineItemRequest,
merchant_id: u64,
order_id: &str,
) -> OrderCancellineitemCall<'a, C>
pub fn cancellineitem( &self, request: OrdersCancelLineItemRequest, merchant_id: u64, order_id: &str, ) -> OrderCancellineitemCall<'a, C>
Create a builder to help you perform the following task:
Cancels a line item, making a full refund.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn canceltestorderbycustomer(
&self,
request: OrdersCancelTestOrderByCustomerRequest,
merchant_id: u64,
order_id: &str,
) -> OrderCanceltestorderbycustomerCall<'a, C>
pub fn canceltestorderbycustomer( &self, request: OrdersCancelTestOrderByCustomerRequest, merchant_id: u64, order_id: &str, ) -> OrderCanceltestorderbycustomerCall<'a, C>
Create a builder to help you perform the following task:
Sandbox only. Cancels a test order for customer-initiated cancellation.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the test order to cancel.
Sourcepub fn createtestorder(
&self,
request: OrdersCreateTestOrderRequest,
merchant_id: u64,
) -> OrderCreatetestorderCall<'a, C>
pub fn createtestorder( &self, request: OrdersCreateTestOrderRequest, merchant_id: u64, ) -> OrderCreatetestorderCall<'a, C>
Create a builder to help you perform the following task:
Sandbox only. Creates a test order.
Arguments
request- No description provided.merchantId- The ID of the account that should manage the order. This cannot be a multi-client account.
Sourcepub fn createtestreturn(
&self,
request: OrdersCreateTestReturnRequest,
merchant_id: u64,
order_id: &str,
) -> OrderCreatetestreturnCall<'a, C>
pub fn createtestreturn( &self, request: OrdersCreateTestReturnRequest, merchant_id: u64, order_id: &str, ) -> OrderCreatetestreturnCall<'a, C>
Create a builder to help you perform the following task:
Sandbox only. Creates a test return.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn custombatch(
&self,
request: OrdersCustomBatchRequest,
) -> OrderCustombatchCall<'a, C>
pub fn custombatch( &self, request: OrdersCustomBatchRequest, ) -> OrderCustombatchCall<'a, C>
Create a builder to help you perform the following task:
Retrieves or modifies multiple orders in a single request.
Arguments
request- No description provided.
Sourcepub fn get(&self, merchant_id: u64, order_id: &str) -> OrderGetCall<'a, C>
pub fn get(&self, merchant_id: u64, order_id: &str) -> OrderGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves an order from your Merchant Center account.
Arguments
merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn getbymerchantorderid(
&self,
merchant_id: u64,
merchant_order_id: &str,
) -> OrderGetbymerchantorderidCall<'a, C>
pub fn getbymerchantorderid( &self, merchant_id: u64, merchant_order_id: &str, ) -> OrderGetbymerchantorderidCall<'a, C>
Create a builder to help you perform the following task:
Retrieves an order using merchant order id.
Arguments
merchantId- The ID of the account that manages the order. This cannot be a multi-client account.merchantOrderId- The merchant order id to be looked for.
Sourcepub fn gettestordertemplate(
&self,
merchant_id: u64,
template_name: &str,
) -> OrderGettestordertemplateCall<'a, C>
pub fn gettestordertemplate( &self, merchant_id: u64, template_name: &str, ) -> OrderGettestordertemplateCall<'a, C>
Create a builder to help you perform the following task:
Sandbox only. Retrieves an order template that can be used to quickly create a new order in sandbox.
Arguments
merchantId- The ID of the account that should manage the order. This cannot be a multi-client account.templateName- The name of the template to retrieve.
Sourcepub fn instorerefundlineitem(
&self,
request: OrdersInStoreRefundLineItemRequest,
merchant_id: u64,
order_id: &str,
) -> OrderInstorerefundlineitemCall<'a, C>
pub fn instorerefundlineitem( &self, request: OrdersInStoreRefundLineItemRequest, merchant_id: u64, order_id: &str, ) -> OrderInstorerefundlineitemCall<'a, C>
Create a builder to help you perform the following task:
Notifies that item return and refund was handled directly by merchant outside of Google payments processing (e.g. cash refund done in store).
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn list(&self, merchant_id: u64) -> OrderListCall<'a, C>
pub fn list(&self, merchant_id: u64) -> OrderListCall<'a, C>
Create a builder to help you perform the following task:
Lists the orders in your Merchant Center account.
Arguments
merchantId- The ID of the account that manages the order. This cannot be a multi-client account.
Sourcepub fn refund(
&self,
request: OrdersRefundRequest,
merchant_id: u64,
order_id: &str,
) -> OrderRefundCall<'a, C>
pub fn refund( &self, request: OrdersRefundRequest, merchant_id: u64, order_id: &str, ) -> OrderRefundCall<'a, C>
Create a builder to help you perform the following task:
Deprecated, please use returnRefundLineItem instead.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order to refund.
Sourcepub fn rejectreturnlineitem(
&self,
request: OrdersRejectReturnLineItemRequest,
merchant_id: u64,
order_id: &str,
) -> OrderRejectreturnlineitemCall<'a, C>
pub fn rejectreturnlineitem( &self, request: OrdersRejectReturnLineItemRequest, merchant_id: u64, order_id: &str, ) -> OrderRejectreturnlineitemCall<'a, C>
Create a builder to help you perform the following task:
Rejects return on an line item.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn returnlineitem(
&self,
request: OrdersReturnLineItemRequest,
merchant_id: u64,
order_id: &str,
) -> OrderReturnlineitemCall<'a, C>
pub fn returnlineitem( &self, request: OrdersReturnLineItemRequest, merchant_id: u64, order_id: &str, ) -> OrderReturnlineitemCall<'a, C>
Create a builder to help you perform the following task:
Returns a line item.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn returnrefundlineitem(
&self,
request: OrdersReturnRefundLineItemRequest,
merchant_id: u64,
order_id: &str,
) -> OrderReturnrefundlineitemCall<'a, C>
pub fn returnrefundlineitem( &self, request: OrdersReturnRefundLineItemRequest, merchant_id: u64, order_id: &str, ) -> OrderReturnrefundlineitemCall<'a, C>
Create a builder to help you perform the following task:
Returns and refunds a line item. Note that this method can only be called on fully shipped orders.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn setlineitemmetadata(
&self,
request: OrdersSetLineItemMetadataRequest,
merchant_id: u64,
order_id: &str,
) -> OrderSetlineitemmetadataCall<'a, C>
pub fn setlineitemmetadata( &self, request: OrdersSetLineItemMetadataRequest, merchant_id: u64, order_id: &str, ) -> OrderSetlineitemmetadataCall<'a, C>
Create a builder to help you perform the following task:
Sets (overrides) merchant provided annotations on the line item.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn shiplineitems(
&self,
request: OrdersShipLineItemsRequest,
merchant_id: u64,
order_id: &str,
) -> OrderShiplineitemCall<'a, C>
pub fn shiplineitems( &self, request: OrdersShipLineItemsRequest, merchant_id: u64, order_id: &str, ) -> OrderShiplineitemCall<'a, C>
Create a builder to help you perform the following task:
Marks line item(s) as shipped.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn updatelineitemshippingdetails(
&self,
request: OrdersUpdateLineItemShippingDetailsRequest,
merchant_id: u64,
order_id: &str,
) -> OrderUpdatelineitemshippingdetailCall<'a, C>
pub fn updatelineitemshippingdetails( &self, request: OrdersUpdateLineItemShippingDetailsRequest, merchant_id: u64, order_id: &str, ) -> OrderUpdatelineitemshippingdetailCall<'a, C>
Create a builder to help you perform the following task:
Updates ship by and delivery by dates for a line item.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn updatemerchantorderid(
&self,
request: OrdersUpdateMerchantOrderIdRequest,
merchant_id: u64,
order_id: &str,
) -> OrderUpdatemerchantorderidCall<'a, C>
pub fn updatemerchantorderid( &self, request: OrdersUpdateMerchantOrderIdRequest, merchant_id: u64, order_id: &str, ) -> OrderUpdatemerchantorderidCall<'a, C>
Create a builder to help you perform the following task:
Updates the merchant order ID for a given order.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.
Sourcepub fn updateshipment(
&self,
request: OrdersUpdateShipmentRequest,
merchant_id: u64,
order_id: &str,
) -> OrderUpdateshipmentCall<'a, C>
pub fn updateshipment( &self, request: OrdersUpdateShipmentRequest, merchant_id: u64, order_id: &str, ) -> OrderUpdateshipmentCall<'a, C>
Create a builder to help you perform the following task:
Updates a shipment’s status, carrier, and/or tracking ID.
Arguments
request- No description provided.merchantId- The ID of the account that manages the order. This cannot be a multi-client account.orderId- The ID of the order.